@@ -9,14 +9,13 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Помилка запиту, Nextcloud зараз у режимі обслуговування!",
     "Unread articles" : "Непрочитані статті",
     "Use system cron for updates" : "Використовуйте системний cron для оновлень",
-    "Purge interval" : "Очистити оновлення",
     "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
     "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
     "Maximum redirects" : "Максимум перенаправлень",
     "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
     "Explore Service URL" : "URL сервісу дослідження",
     "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
-    "Download" : "Завантажити",
+    "Download" : "Звантажити",
     "Close" : "Закрити",
     "No articles available" : "Немає доступних статей",
     "No unread articles available" : "Немає непрочитаних записів",
@@ -25,13 +24,13 @@ OC.L10N.register(
     "Unstar article" : "Зняти позначку статті",
     "Keep article unread" : "Залишити статтю непрочитаною",
     "Remove keep article unread" : "Позначити статтю як прочитану",
-    "Share" : "Поділитися",
+    "Share" : "Спільний доступ",
     "Username" : "Ім'я користувача",
     "by" : "по",
     "from" : "З",
     "Play audio" : "Відтворення аудіо",
-    "Download audio" : "Завантажити аудіо",
-    "Download video" : "Завантажити відео",
+    "Download audio" : "Звантажити аудіо",
+    "Download video" : "Звантажити відео",
     "Keyboard shortcut" : "Сполучення клавіш",
     "Description" : "Опис",
     "right" : "праворуч",
@@ -45,26 +44,26 @@ OC.L10N.register(
     "Toggle expand article in compact view" : "Переключити статтю в компактний режим",
     "Refresh" : "Оновити",
     "Load next feed" : "Завантажити наступну стрічку",
-    "Load previous feed" : "Завантажити попередню стрічку",
-    "Load previous folder" : "Завантажити попередню теку",
-    "Load next folder" : "Завантажити наступну теку",
+    "Load previous feed" : "Звантажити попередню стрічку",
+    "Load previous folder" : "Звантажити попередній каталог",
+    "Load next folder" : "Завантажити наступний каталог",
     "Scroll to active navigation entry" : "Перехід до обраного елементу",
-    "Mark current article's feed/folder read" : "Зробити поточну подачу/теку артиклю лише для читання",
+    "Mark current article's feed/folder read" : "Позначити поточну видачу/каталог зі статтями прочитаними",
     "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Установіть і налаштуйте швидший паралельний засіб оновлення, який використовує API оновлення програми Новини",
     "Subscribe" : "Підписатися",
     "Web address" : "Веб адреса",
     "Feed exists already!" : "Стрічка вже існує !",
-    "Folder" : "Папка",
-    "No folder" : "Немає теки",
-    "New folder" : "Нова тека",
-    "Folder name" : "Ім'я теки",
+    "Folder" : "Каталог",
+    "No folder" : "Відсутній каталог",
+    "New folder" : "Новий каталог",
+    "Folder name" : "Назва каталогу",
     "Go back" : "Повернутися назад",
-    "Folder exists already!" : "Тека вже існує !",
+    "Folder exists already!" : "Каталог вже існує !",
     "Credentials" : "Облікові дані",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
     "Password" : "Пароль",
-    "New Folder" : "Нова тека",
+    "New Folder" : "Новий каталог",
     "Create" : "Створити",
     "Explore" : "Дослідити",
     "Update failed more than 50 times" : "Помилка оновлення понад 50 разів",
@@ -73,13 +72,15 @@ OC.L10N.register(
     "Rename" : "Перейменувати",
     "Menu" : "Меню",
     "Mark read" : "Позначити як прочитане",
-    "Newest first" : "Новіші попереду",
-    "Oldest first" : "Старіші попереду",
+    "Newest first" : "Новіші спочатку",
+    "Oldest first" : "Старіші спочатку",
+    "Enable full text" : "Увімкнути повнотекстовий",
+    "Disable full text" : "Вимкнути повнотекстовий",
     "Delete" : "Вилучити",
     "Dismiss" : "Припинити",
     "Collapse" : "Згорнути",
-    "Deleted folder" : "Вилучені теки",
-    "Undo delete folder" : "Скасувати вилучення теки",
+    "Deleted folder" : "Вилучений каталог",
+    "Undo delete folder" : "Скасувати вилучення каталогу",
     "Starred" : "Помічені зірочкою",
     "All articles" : "Всі статті",
     "Settings" : "Налаштування",
