@@ -53,8 +53,8 @@ class Application extends App implements IBootstrap
      * List of default settings
      */
     public const DEFAULT_SETTINGS = [
-        'autoPurgeMinimumInterval' => 60,
         'autoPurgeCount'           => 200,
+        'purgeUnread'              => false,
         'maxRedirects'             => 10,
         'feedFetcherTimeout'       => 60,
         'useCronUpdates'           => true,
